pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn account<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn account<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The unique name for the account. An account is also known as the project or tenant.
Sourcepub fn container<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn container<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The unique (within an account) name for the container. The container name must be from 1 to 256 characters long and can start with any character and contain any pattern. Character set must be UTF-8. The container name cannot contain a slash (/) character because this character delimits the container and object name. For example, the path /v1/account/www/pages specifies the www container, not the www/pages container.
Sourcepub fn delimiter<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn delimiter<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The delimiter is a single character used to split object names to present a pseudo-directory hierarchy of objects. When combined with a prefix query, this enables API users to simulate and traverse the objects in a container as if they were in a directory tree.
Sourcepub fn end_marker<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn end_marker<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
For a string value, x, constrains the list to items whose names are less than x.
Sourcepub fn format<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn format<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The response format. Valid values are json, xml, or plain. The default is plain. If you append the format=xml or format=json query parameter to the storage account URL, the response shows extended container information serialized in that format. If you append the format=plain query parameter, the response lists the container names separated by newlines.
Sourcepub fn limit(&mut self, value: u32) -> &mut Self
pub fn limit(&mut self, value: u32) -> &mut Self
For an integer value n, limits the number of results to n.
Sourcepub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
For a string value, x, constrains the list to items whose names are greater than x.
Sourcepub fn prefix<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn prefix<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Only objects with this prefix will be returned. When combined with a delimiter query, this enables API users to simulate and traverse the objects in a container as if they were in a directory tree.