Module get

Module get 

Downloads the object content and gets the object metadata. This operation returns the object metadata in the response headers and the object content in the response body.

Structs

Request
RequestBuilder
Builder for Request.

Enums

RequestBuilderError
Error type for RequestBuilder