Downloads the object content and gets the object metadata. This operation returns the object metadata in the response headers and the object content in the response body.
Structs
- Request
- Request
Builder - Builder for
Request.
Enums
- Request
Builder Error - Error type for RequestBuilder