pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn account<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn account<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The unique name for the account. An account is also known as the project or tenant.
Sourcepub fn bulk_delete(&mut self, value: bool) -> &mut Self
pub fn bulk_delete(&mut self, value: bool) -> &mut Self
When the bulk-delete query parameter is present in the POST request, multiple objects or containers can be deleted with a single request. See Bulk Delete for how this feature is used.
Sourcepub fn container<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn container<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The unique (within an account) name for the container. The container name must be from 1 to 256 characters long and can start with any character and contain any pattern. Character set must be UTF-8. The container name cannot contain a slash (/) character because this character delimits the container and object name. For example, the path /v1/account/www/pages specifies the www container, not the www/pages container.
Sourcepub fn extract_archive(&mut self, value: bool) -> &mut Self
pub fn extract_archive(&mut self, value: bool) -> &mut Self
When the extract-archive query parameter is present in the POST request, an archive (tar file) is uploaded and extracted to create multiple objects. See Extract Archive for how this feature is used.
Sourcepub fn filename<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn filename<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Overrides the default file name. Object Storage generates a default file name for GET temporary URLs that is based on the object name. Object Storage returns this value in the Content-Disposition response header. Browsers can interpret this file name value as a file attachment to save. For more information about temporary URLs, see Temporary URL middleware.
Sourcepub fn multipart_manifest<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn multipart_manifest<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
If you include the multipart-manifest=get query parameter and the object is a large object, the object contents are not returned. Instead, the manifest is returned in the X-Object-Manifest response header for dynamic large objects or in the response body for static large objects.
Sourcepub fn object<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn object<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The unique name for the object.
Sourcepub fn symlink<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn symlink<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
If you include the symlink=get query parameter and the object is a symlink, then the response will include data and metadata from the symlink itself rather than from the target.
Sourcepub fn temp_url_expires(&mut self, value: i32) -> &mut Self
pub fn temp_url_expires(&mut self, value: i32) -> &mut Self
The date and time in UNIX Epoch time stamp format or ISO 8601 UTC timestamp when the signature for temporary URLs expires. For example, 1440619048 or 2015-08-26T19:57:28Z is equivalent to Mon, Wed, 26 Aug 2015 19:57:28 GMT. For more information about temporary URLs, see Temporary URL middleware.
Sourcepub fn temp_url_sig<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn temp_url_sig<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
Used with temporary URLs to sign the request with an HMAC-SHA1 cryptographic signature that defines the allowed HTTP method, expiration date, full path to the object, and the secret key for the temporary URL. For more information about temporary URLs, see Temporary URL middleware.